#ifndef _GSKMM_CONFIG_H
#define _GSKMM_CONFIG_H

#include <gdkmmconfig.h>

/* Define to omit deprecated API from gskmm. */
/* #undef GSKMM_DISABLE_DEPRECATED */

/* Major version number of gskmm. */
/* #undef GSKMM_MAJOR_VERSION */

/* Minor version number of gskmm. */
/* #undef GSKMM_MINOR_VERSION */

/* Micro version number of gskmm. */
/* #undef GSKMM_MICRO_VERSION */

/* Enable DLL-specific stuff only when not building a static library */
#if !defined(__CYGWIN__) && defined(_WIN32) && !defined(GSKMM_STATIC_LIB)
# define GSKMM_DLL 1
#endif

#ifdef GSKMM_DLL
# if defined(GDKMM_BUILD) || defined(GSKMM_BUILD) || defined(GTKMM_BUILD)
#  define GSKMM_API __declspec(dllexport)
# elif !defined (__GNUC__)
#  define GSKMM_API __declspec(dllimport)
# else /* don't dllimport classes/methods on GCC/MinGW */
#  define GSKMM_API
# endif /* G?KMM_BUILD */
#else
/* Build a static library or a non-native-Windows library */
# define GSKMM_API
#endif /* GSKMM_DLL */

#endif /* _GSKMM_CONFIG_H */
