// Generated by gmmproc 2.88.0 -- DO NOT MODIFY!
#ifndef _GTKMM_MULTIFILTER_H
#define _GTKMM_MULTIFILTER_H


#include <glibmm/ustring.h>
#include <sigc++/sigc++.h>

/* Copyright (C) 2020 The gtkmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#include <gtkmm/filter.h>
#include <gtkmm/buildable.h>
#include <giomm/listmodel.h>


#ifndef DOXYGEN_SHOULD_SKIP_THIS
using GtkMultiFilter = struct _GtkMultiFilter;
using GtkMultiFilterClass = struct _GtkMultiFilterClass;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */


#ifndef DOXYGEN_SHOULD_SKIP_THIS
namespace Gtk
{ class GTKMM_API MultiFilter_Class; } // namespace Gtk
#endif //DOXYGEN_SHOULD_SKIP_THIS

#ifndef DOXYGEN_SHOULD_SKIP_THIS
using GtkAnyFilter = struct _GtkAnyFilter;
using GtkAnyFilterClass = struct _GtkAnyFilterClass;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */


#ifndef DOXYGEN_SHOULD_SKIP_THIS
namespace Gtk
{ class GTKMM_API AnyFilter_Class; } // namespace Gtk
#endif //DOXYGEN_SHOULD_SKIP_THIS

#ifndef DOXYGEN_SHOULD_SKIP_THIS
using GtkEveryFilter = struct _GtkEveryFilter;
using GtkEveryFilterClass = struct _GtkEveryFilterClass;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */


#ifndef DOXYGEN_SHOULD_SKIP_THIS
namespace Gtk
{ class GTKMM_API EveryFilter_Class; } // namespace Gtk
#endif //DOXYGEN_SHOULD_SKIP_THIS

namespace Gtk
{

/** Combining multiple filters.
 *
 * %Gtk::MultiFilter is the base type that implements support for handling
 * multiple filters.
 *
 * @ingroup ListView
 * @newin{3,98}
 */

class GTKMM_API MultiFilter : public Filter, public Gio::ListModel, public Buildable
{
  
#ifndef DOXYGEN_SHOULD_SKIP_THIS

public:
  using CppObjectType = MultiFilter;
  using CppClassType = MultiFilter_Class;
  using BaseObjectType = GtkMultiFilter;
  using BaseClassType = GtkMultiFilterClass;

  // noncopyable
  MultiFilter(const MultiFilter&) = delete;
  MultiFilter& operator=(const MultiFilter&) = delete;

private:  friend class MultiFilter_Class;
  static CppClassType multifilter_class_;

protected:
  explicit MultiFilter(const Glib::ConstructParams& construct_params);
  explicit MultiFilter(GtkMultiFilter* castitem);

#endif /* DOXYGEN_SHOULD_SKIP_THIS */

public:

  MultiFilter(MultiFilter&& src) noexcept;
  MultiFilter& operator=(MultiFilter&& src) noexcept;

  ~MultiFilter() noexcept override;

  /** Get the GType for this class, for use with the underlying GObject type system.
   */
  static GType get_type()      G_GNUC_CONST;

#ifndef DOXYGEN_SHOULD_SKIP_THIS


  static GType get_base_type() G_GNUC_CONST;
#endif

  ///Provides access to the underlying C GObject.
  GtkMultiFilter*       gobj()       { return reinterpret_cast<GtkMultiFilter*>(gobject_); }

  ///Provides access to the underlying C GObject.
  const GtkMultiFilter* gobj() const { return reinterpret_cast<GtkMultiFilter*>(gobject_); }

  ///Provides access to the underlying C instance. The caller is responsible for unrefing it. Use when directly setting fields in structs.
  GtkMultiFilter* gobj_copy();

private:

  
protected:
  MultiFilter();

public:
 

  /** Adds a filter.
   * 
   * @param filter A filter to add.
   */
  void append(const Glib::RefPtr<Filter>& filter);
  
  /** Removes a filter.
   * 
   * If @a position is larger than the number of filters,
   * nothing happens.
   * 
   * @param position Position of filter to remove.
   */
  void remove(guint position);

  /** The type of items.
   * 
   * See Gio::ListModel::get_item_type().
   * 
   * @newin{4,8}
   *
   * @return A PropertyProxy_ReadOnly that allows you to get the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy_ReadOnly< GType > property_item_type() const;


  /** The number of items.
   * 
   * See Gio::ListModel::get_n_items().
   * 
   * @newin{4,8}
   *
   * Default value: 0
   *
   * @return A PropertyProxy_ReadOnly that allows you to get the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy_ReadOnly< unsigned int > property_n_items() const;


public:

public:
  //C++ methods used to invoke GTK+ virtual functions:

protected:
  //GTK+ Virtual Functions (override these to change behaviour):

  //Default Signal Handlers::


};

/** Matches when at least one filter matches.
 *
 * %Gtk::AnyFilter is a subclass of Gtk::MultiFilter that matches an item
 * when at least one of its filters matches.
 *
 * @ingroup ListView
 * @newin{3,98}
 */

class GTKMM_API AnyFilter : public MultiFilter
{
  
#ifndef DOXYGEN_SHOULD_SKIP_THIS

public:
  using CppObjectType = AnyFilter;
  using CppClassType = AnyFilter_Class;
  using BaseObjectType = GtkAnyFilter;
  using BaseClassType = GtkAnyFilterClass;

  // noncopyable
  AnyFilter(const AnyFilter&) = delete;
  AnyFilter& operator=(const AnyFilter&) = delete;

private:  friend class AnyFilter_Class;
  static CppClassType anyfilter_class_;

protected:
  explicit AnyFilter(const Glib::ConstructParams& construct_params);
  explicit AnyFilter(GtkAnyFilter* castitem);

#endif /* DOXYGEN_SHOULD_SKIP_THIS */

public:

  AnyFilter(AnyFilter&& src) noexcept;
  AnyFilter& operator=(AnyFilter&& src) noexcept;

  ~AnyFilter() noexcept override;

  /** Get the GType for this class, for use with the underlying GObject type system.
   */
  static GType get_type()      G_GNUC_CONST;

#ifndef DOXYGEN_SHOULD_SKIP_THIS


  static GType get_base_type() G_GNUC_CONST;
#endif

  ///Provides access to the underlying C GObject.
  GtkAnyFilter*       gobj()       { return reinterpret_cast<GtkAnyFilter*>(gobject_); }

  ///Provides access to the underlying C GObject.
  const GtkAnyFilter* gobj() const { return reinterpret_cast<GtkAnyFilter*>(gobject_); }

  ///Provides access to the underlying C instance. The caller is responsible for unrefing it. Use when directly setting fields in structs.
  GtkAnyFilter* gobj_copy();

private:

      
protected:
  AnyFilter();

public:
  
  static Glib::RefPtr<AnyFilter> create();


public:

public:
  //C++ methods used to invoke GTK+ virtual functions:

protected:
  //GTK+ Virtual Functions (override these to change behaviour):

  //Default Signal Handlers::


};

/** Matches when each of its filter matches.
 *
 * %Gtk::EveryFilter is a subclass of Gtk::MultiFilter that matches an item
 * when each of its filters matches.
 *
 * @ingroup ListView
 * @newin{3,98}
 */

class GTKMM_API EveryFilter : public MultiFilter
{
  
#ifndef DOXYGEN_SHOULD_SKIP_THIS

public:
  using CppObjectType = EveryFilter;
  using CppClassType = EveryFilter_Class;
  using BaseObjectType = GtkEveryFilter;
  using BaseClassType = GtkEveryFilterClass;

  // noncopyable
  EveryFilter(const EveryFilter&) = delete;
  EveryFilter& operator=(const EveryFilter&) = delete;

private:  friend class EveryFilter_Class;
  static CppClassType everyfilter_class_;

protected:
  explicit EveryFilter(const Glib::ConstructParams& construct_params);
  explicit EveryFilter(GtkEveryFilter* castitem);

#endif /* DOXYGEN_SHOULD_SKIP_THIS */

public:

  EveryFilter(EveryFilter&& src) noexcept;
  EveryFilter& operator=(EveryFilter&& src) noexcept;

  ~EveryFilter() noexcept override;

  /** Get the GType for this class, for use with the underlying GObject type system.
   */
  static GType get_type()      G_GNUC_CONST;

#ifndef DOXYGEN_SHOULD_SKIP_THIS


  static GType get_base_type() G_GNUC_CONST;
#endif

  ///Provides access to the underlying C GObject.
  GtkEveryFilter*       gobj()       { return reinterpret_cast<GtkEveryFilter*>(gobject_); }

  ///Provides access to the underlying C GObject.
  const GtkEveryFilter* gobj() const { return reinterpret_cast<GtkEveryFilter*>(gobject_); }

  ///Provides access to the underlying C instance. The caller is responsible for unrefing it. Use when directly setting fields in structs.
  GtkEveryFilter* gobj_copy();

private:

      
protected:
  EveryFilter();

public:
  
  static Glib::RefPtr<EveryFilter> create();


public:

public:
  //C++ methods used to invoke GTK+ virtual functions:

protected:
  //GTK+ Virtual Functions (override these to change behaviour):

  //Default Signal Handlers::


};

} // namespace Gtk


namespace Glib
{
  /** A Glib::wrap() method for this object.
   *
   * @param object The C instance.
   * @param take_copy False if the result should take ownership of the C instance. True if it should take a new copy or ref.
   * @result A C++ instance that wraps this C instance.
   *
   * @relates Gtk::MultiFilter
   */
  GTKMM_API
  Glib::RefPtr<Gtk::MultiFilter> wrap(GtkMultiFilter* object, bool take_copy = false);
}


namespace Glib
{
  /** A Glib::wrap() method for this object.
   *
   * @param object The C instance.
   * @param take_copy False if the result should take ownership of the C instance. True if it should take a new copy or ref.
   * @result A C++ instance that wraps this C instance.
   *
   * @relates Gtk::AnyFilter
   */
  GTKMM_API
  Glib::RefPtr<Gtk::AnyFilter> wrap(GtkAnyFilter* object, bool take_copy = false);
}


namespace Glib
{
  /** A Glib::wrap() method for this object.
   *
   * @param object The C instance.
   * @param take_copy False if the result should take ownership of the C instance. True if it should take a new copy or ref.
   * @result A C++ instance that wraps this C instance.
   *
   * @relates Gtk::EveryFilter
   */
  GTKMM_API
  Glib::RefPtr<Gtk::EveryFilter> wrap(GtkEveryFilter* object, bool take_copy = false);
}


#endif /* _GTKMM_MULTIFILTER_H */

