// Generated by gmmproc 2.88.0 -- DO NOT MODIFY!
#ifndef _GTKMM_BUILDERCSCOPE_H
#define _GTKMM_BUILDERCSCOPE_H


#include <glibmm/ustring.h>
#include <sigc++/sigc++.h>

/* Copyright (C) 2020 The gtkmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#include <glibmm/object.h>
#include <gtkmm/builderscope.h>


#ifndef DOXYGEN_SHOULD_SKIP_THIS
using GtkBuilderCScope = struct _GtkBuilderCScope;
using GtkBuilderCScopeClass = struct _GtkBuilderCScopeClass;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */


#ifndef DOXYGEN_SHOULD_SKIP_THIS
namespace Gtk
{ class GTKMM_API BuilderCScope_Class; } // namespace Gtk
#endif //DOXYGEN_SHOULD_SKIP_THIS

namespace Gtk
{
#ifndef DOXYGEN_SHOULD_SKIP_THIS
/** Bindings for Gtk::Builder.
 *
 * gtkmm applications probably don't need this class.
 *
 * %Gtk::BuilderCScope provides support to Gtk::Builder, primarily
 * for looking up programming-language-specific values for strings that are
 * given in a Gtk::Builder UI file.
 *
 * @see Gtk::Builder
 * @newin{3,98}
 */

class GTKMM_API BuilderCScope : public Glib::Object, public BuilderScope
{
  
#ifndef DOXYGEN_SHOULD_SKIP_THIS

public:
  using CppObjectType = BuilderCScope;
  using CppClassType = BuilderCScope_Class;
  using BaseObjectType = GtkBuilderCScope;
  using BaseClassType = GtkBuilderCScopeClass;

  // noncopyable
  BuilderCScope(const BuilderCScope&) = delete;
  BuilderCScope& operator=(const BuilderCScope&) = delete;

private:  friend class BuilderCScope_Class;
  static CppClassType buildercscope_class_;

protected:
  explicit BuilderCScope(const Glib::ConstructParams& construct_params);
  explicit BuilderCScope(GtkBuilderCScope* castitem);

#endif /* DOXYGEN_SHOULD_SKIP_THIS */

public:

  BuilderCScope(BuilderCScope&& src) noexcept;
  BuilderCScope& operator=(BuilderCScope&& src) noexcept;

  ~BuilderCScope() noexcept override;

  /** Get the GType for this class, for use with the underlying GObject type system.
   */
  static GType get_type()      G_GNUC_CONST;

#ifndef DOXYGEN_SHOULD_SKIP_THIS


  static GType get_base_type() G_GNUC_CONST;
#endif

  ///Provides access to the underlying C GObject.
  GtkBuilderCScope*       gobj()       { return reinterpret_cast<GtkBuilderCScope*>(gobject_); }

  ///Provides access to the underlying C GObject.
  const GtkBuilderCScope* gobj() const { return reinterpret_cast<GtkBuilderCScope*>(gobject_); }

  ///Provides access to the underlying C instance. The caller is responsible for unrefing it. Use when directly setting fields in structs.
  GtkBuilderCScope* gobj_copy();

private:

  
protected:
  BuilderCScope();

public:
  
  static Glib::RefPtr<BuilderCScope> create();


public:

public:
  //C++ methods used to invoke GTK+ virtual functions:

protected:
  //GTK+ Virtual Functions (override these to change behaviour):

  //Default Signal Handlers::


};
#endif /* DOXYGEN_SHOULD_SKIP_THIS */

} // namespace Gtk


namespace Glib
{
  /** A Glib::wrap() method for this object.
   *
   * @param object The C instance.
   * @param take_copy False if the result should take ownership of the C instance. True if it should take a new copy or ref.
   * @result A C++ instance that wraps this C instance.
   *
   * @relates Gtk::BuilderCScope
   */
  GTKMM_API
  Glib::RefPtr<Gtk::BuilderCScope> wrap(GtkBuilderCScope* object, bool take_copy = false);
}


#endif /* _GTKMM_BUILDERCSCOPE_H */

