/* gdkmm.h
 *
 * Copyright (C) 2002 The gtkmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <https://www.gnu.org/licenses/>.
 */

#ifndef _GDKMM_GDKMM_H_
#define _GDKMM_GDKMM_H_

#include <gdkmm/applaunchcontext.h>
#include <gdkmm/cairocontext.h>
#include <gdkmm/cicpparams.h>
#include <gdkmm/contentformatsbuilder.h>
#include <gdkmm/clipboard.h>
#include <gdkmm/colorstate.h>
#include <gdkmm/cursor.h>
#include <gdkmm/devicepad.h>
#include <gdkmm/devicetool.h>
#include <gdkmm/devicewithpad.h>
#include <gdkmm/display.h>
#include <gdkmm/displaymanager.h>
#include <gdkmm/dmabufformats.h>
#include <gdkmm/dmabuftexture.h>
#include <gdkmm/dmabuftexturebuilder.h>
#include <gdkmm/dragsurface.h>
#include <gdkmm/dragsurfaceimpl.h>
#include <gdkmm/drop.h>
#include <gdkmm/event.h>
#include <gdkmm/frameclock.h>
#include <gdkmm/general.h>
#include <gdkmm/glcontext.h>
#include <gdkmm/gltexture.h>
#include <gdkmm/gltexturebuilder.h>
#include <gdkmm/graphene_rect.h>
#include <gdkmm/memorytexture.h>
#include <gdkmm/memorytexturebuilder.h>
#include <gdkmm/monitor.h>
#include <gdkmm/paintable.h>
#include <gdkmm/pixbuf.h>
#ifndef GDKMM_DISABLE_DEPRECATED
# include <gdkmm/pixbufanimation.h>
#endif
#include <gdkmm/pixbufformat.h>
#include <gdkmm/pixbufloader.h>
#include <gdkmm/popup.h>
#include <gdkmm/popupsurfaceimpl.h>
#include <gdkmm/rectangle.h>
#include <gdkmm/seat.h>
#include <gdkmm/snapshot.h>
#include <gdkmm/surface.h>
#include <gdkmm/texture.h>
#include <gdkmm/texturedownloader.h>
#include <gdkmm/toplevel.h>
#include <gdkmm/toplevelsurfaceimpl.h>

#endif /* _GDKMM_GDKMM_H_ */
